# Ghost-Content MCP Server

An MCP Server for the Ghost-Content API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the Ghost-Content API.

| Tool                  | Description                                                                     |
| --------------------- | ------------------------------------------------------------------------------- |
| `browse_posts`        | Browse posts. Parameters: include, fields, filter, limit, page, order, formats. |
| `read_post_by_id`     | Read a post by its ID. Parameters: id, include, fields, formats.                |
| `read_post_by_slug`   | Read a post by its slug. Parameters: slug, include, fields, formats.            |
| `browse_authors`      | Browse authors. Parameters: include, fields, filter, limit, page, order.        |
| `read_author_by_id`   | Read an author by ID. Parameters: id, include, fields.                          |
| `read_author_by_slug` | Read an author by slug. Parameters: slug, include, fields.                      |
| `browse_tags`         | Browse tags. Parameters: include, fields, filter, limit, page, order.           |
| `read_tag_by_id`      | Read a tag by ID. Parameters: id, include, fields.                              |
| `read_tag_by_slug`    | Read a tag by slug. Parameters: slug, include, fields.                          |
| `browse_pages`        | Browse pages. Parameters: include, fields, filter, limit, page, order, formats. |
| `read_page_by_id`     | Read a page by ID. Parameters: id, include, fields, formats.                    |
| `read_page_by_slug`   | Read a page by slug. Parameters: slug, include, fields, formats.                |
| `browse_tiers`        | Browse tiers. Parameters: include, fields, filter, limit, page, order.          |
| `browse_settings`     | Browse site settings.                                                           |
